# PyLSB
This library provides a convenient way to retrieve the content of the Legacy
Standard Bible. It is platform agnostic, saves data into an easy to parse JSON
file, and retrieves all data from the official website
(https://read.lsbible.org/).

This software is not officially endorsed by, or affiliated with, The Lockman
Foundation or Three Sixteen Publishing Inc. (the copyright holders of the LSB)
in any way. I hold no responsibility for your usage of this software. It was
created as a hobby/mild-learning project for myself as this is the translation I
personally read. To support the translators and printers, consider
[purchasing](https://316publishing.com/collections/lsb) your own copy of the
LSB.

# How to Use
to be updated
